bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 25. Aventiure
___________________________________________________ #### <Wie die herren alle zen Hevnen fvren>
| ### v lazen daz beliben wie si gebaren hie ### hochgemvoter reken die gefuoren nie ### so rehte herlichen in deheines kvniges lant ### si heten swaz si wolten beide wafen vn– gewant ### Der vogt von dem Rine cleidete sine man ### sechzech vn– tvsent als ich vernomen han ### vn– nivn tvsent chnehte gen der hohcit ### die si da heime liezen die beweint ez sit
###### 1448 | ### Do truoch man daz gereite ze Wormez vzer den hof ### do sprach da von Spire ein alter bischof ### zvo der schoenen voten vnser vruvnde wellent varn ### gen der hohcite got mvose si da bewarn
###### 1449 | ### Do sprach zuo zir kinden div edele vote ### ir soltet hie beliben helde guote ### mir ist getrovmet hint von engestlicher not ### wie allez daz gefuegele in disme lande were tot
###### 1450 | ### Swer sic an trovme wendet sprach do Hagne ### der enweiz der rehten mere niht ze sagene ### wenne ez im zen eren volleclichen ste ### ich wil daz min herre ze hove nach urlovbe gê
###### 1451 | ### Wir svln vil gerne riten in Ecelen lant ### da mag wol dienen kvnige guoter helde hant ### da wir da schovwen mvozen Criemhilt hohcit ### Hagne riet die reise idoch <gerov> ez in sit
###### 1452 | ### Er hetez widerraten wan daz Gernot ### mit vngefuoge im also missebot ### er mant in Sifrides <vrov> Kriemhilt man ### er sprach da von wil Hagne die groze hovereise lan
###### 1453 | ### Do sprach von Trony Hagne durch vorhte ich niht entvo ### swenne ir gebietet helde so svlt ir grifen zvo ### ia rite ich mit iv gerne in Ecelen lant ### sit wart von im <verhavwen> manich helm vn– rant
###### 1454 | ### Div schif bereitet waren da was vil manic man ### swaz si cleider heten die truoch man dar an ### si waren vil vnmuozech vor abendes zit ### si huoben sich von hvse vil harte vroliche sit
###### 1455 | ### Die gecelt vn– ovch die hutten spien man an daz gras ### anderthalp des Rines da daz geseze was ### den kvnich bat noch beliben sin vil schoenes wip ### sie truote noch des nahtes den sinen wetlichen lip
###### 1456 | ### Bvsunen fleutieren huob sic des morgens fruo ### daz si varen solden do grifen si do zvo ### swer liep hete an arme der trivte vrivndes lip ### des schit sit vil mit leide des kvniges Ecelen wip
###### 1457 | ### Div kint der schoenen voten die heten einen man ### kuone vn– getriwen do si do wolten dan ### do sagt ez dem kvnegen sinen mvot [59b] ### er sprach des mvoz ich truoren daz ir die houereise tuot
###### 1458 | ### Er was geheizen Rumolt vn– was im helt zer hant ### er sprach wem welt ir lazen lûte vnd ovch div lant ### daz nieman kan erwenden iv reken iwern mvot ### Kriemhilte mere nie geduhten mich guot
###### 1459 | ### Daz lant si dir bevolhen vn– ovch min kindelin ### vn– diene wol den vrovwen daz ist der wille min ### swem dv sehest weinen dem troste sinen lip ### ia tvot vns nimmer leide des kvnic Ecelen wip
###### 1460 | ### Div ros bereitet waren den kvnigen vn– ir man ### mit minneclichem kvsse schiet vil maniger dan ### dem in hohen mvote lebete do der lip ### daz muose sit beweinen vil manich wetlich wip
###### 1461 | ### Do man die snellen reken sach zen rossen gan ### do kos man vil der vrowen trurichlichen stan ### daz ir vil langez scheiden seite in wol der mvot ### vf grozen schaden ze komen daz herze nieman sampfte tuot
###### 1462 | ### Die snellen Bvrgonden sich vz huoben ### do wart in dem lande ein michel voben ### beidenthalp dr berge weinde wip vn– man ### swe dort ir volch tete si fuoren vrolich dan
###### 1463 | ### Die Niblvnges helde komen mit in dan ### in tvsent halspergen die heime heten lan ### manige schoene vrovwen die si gesahen nimmer me ### Sifrides wunde taten Kriemhilde we
###### 1464 | ### Do schichten si die reisen gen dem Movme dan ### vf durch Ostervranchen die Gvnthers man ### dar leitete sich Hagne dem was ez wol bekant ### ir marschach was Dancwart der helt von Burgonden lant
###### 1465 | ### Do si von Ostervranken gen Swanevelde riten ### da mohte man si kiesen an herlichen siten ### die fursten vnd ir mage die helde lobesam ### an dem zwelften morgen der kvnich zer Tuonovwe kom
###### 1466 | ### Do reit von Troni Hagne zaller vorderost ### er was den Niblvngen ein helflicher trost ### do erbeizte der degen kûne nider vf den sant ### sin ros er harte balde zvo eime bovme gebant
###### 1467 | ### Daz wazzer was engozzen vn– div schif verborgen ### ez ergie den Niblvngen zen grozen sorgen ### wie si komen vbere der wal was in ze bereit ### do erbeizte zvo der erden vil manich riter gemeit
###### 1468 | ### Leide so sprach Hagne mac dir hie wol geschehen ### vogt von dem Rine nv maht dv selbe sehen ### daz wazzer ist enegozzen vil starch ist im sin fluot ### ia wen wir hie verliesen noch hivte manigen reken guot
###### 1469 | ### Waz wizet ir mir Hagne sprach der kvnic her ### durch iwers selbe tvgende <vntrostet> vns niht mer ### den fvrt svlt ir vns svochen hinvber an daz lant ### daz wir von hinnen bringen beide ros vnd <ovch> gewant
###### 1470 | ### Ja enist mir sprach Hagne min leben niht so leit ### daz ich mich welle ertrenken in disen vnden breit ### ê sol von minen handen ersterben manich man [60a] ### in Ecelen landen des ich vil guoten willen han
###### 1471 | ### Belibet bi dem wazzer ir stolzen riter guot ### ich wil die vergen suochen selbe bi der fluot ### die vns bringen vbere in Gelpfrates lant ### do nam der starke Hagne sinen guoten schildes rant
###### 1472 | ### Er was wol gewafent den schilt er dannen truoch ### sinen helm vf gebvnden lieht was er genvoc ### do truoch er ob der brunne ein wafen also breit ### daz ze beiden eken vil harte vreislichen sneit
###### 1473 | ### Do suohte er nah den vergen wider vn– dan ### er horte wazzer giezen losen er began ### in einem schoenen brvnnen taten daz wisiv wip ### die wolten sich da kûlen vn– badeten iren lip
###### 1474 | ### Hagne wart ir innen er sleich in tovgen nach ### do si daz versvnnen do was in dannen gach ### daz si im entrunnen des waren si vil her ### er nam in ir gewete der helt schadete in niht mer
###### 1475 | ### Do sprach daz eine merwip Hadburch was si genant ### edel riter Hagne wir tvon dir hie bekant ### swenne ir vns gebet wider vnser gewant ### wie iv ce den Hvnen iwer houereise ergant
###### 1476 | ### Si swebten sam die vogele vor im vf der fluot ### des hugten im ir sinne starch vn– <gvot> ### swaz si im sagen <wolden> er gelaubete in dester baz ### des er do hin ce in do gerte wol beschieden si im daz
###### 1477 | ### Si sprach ir mvget wol riten in Ecelen lant ### des sece ich iv ce burgen min triwe hie ze hant ### daz helde nie gefuoren in deheiniv riche baz ### nach also grozen eren nv gelovbee werlichen daz
###### 1478 | ### Der rede was do Hagne in sime herzen her ### do gab er in ir kleider vn– svmte sich niht mer ### do si an geleiten ir wunderlich gewant ### do sageten sim rehte die reise in Ecelen lant
###### 1479 | ### Do sprach daz ander merwip div hiez Siglint ### ich wil dich warnen Hagne Aldrians kint ### durch der wete liebe hat min mvome dir gelogen ### kvmstv cen Hunen so bistv sere betrogen
###### 1480 | ### Ia soltu wider keren daz ist an der zit ### wan ir helde kuone also geladen sit ### daz ir sterben muozet in Ecelen lant ### swelhe dar geritent die habent den tot an der hant
###### 1481 | ### Do sprach aber Hagne ir trieget ane not ### wie mohte ez sich gefuegen daz wir alle tot ### solden da beliben durch iemans haz ### si begvnden im div mere sagen kvntlicher baz
###### 1482 | ### Do sprach aber div eine ez mvoz also wesen ### daz iwer einer chan da niht genesen ### niwan des kvniges kapelan daz ist vns wol bekant ### der kvmt gesunt widere in Gunthers lant
###### 1483 | ### Do sprach in grimmem muote der kuene Hagne [60b] ### daz were minen herren muolich ce sagene ### daz wir zen Hvnen solden verliesen alle den lip ### nv ceig vns vberz wazzer allerwisete wip
###### 1484 | ### Si sprach sit dv der verte niht wellest haben rat ### swa oben bi dem wazzer ein herberge stat ### darinne ist ein verge vnd nindert anderswa ### der mere der er vragte der gelovbet er sich da
###### 1485 | ### Dem vngemvoten reken sprach div eine nach ### nv bitet noch er Hagene ia ist iv gar ze gach ### vernemet noch baz div mere wie ir komet vber sant ### dirre march herre der ist Else genant
###### 1486 | ### Sin bruoder der ist geheizen der degen Gelpfart ### ein <herre> in Beierlande vil mvelich ez iu stat ### welt ir durch sine marke ir svlt ivch wol bewarn ### vn– sult ovch mit den vergen vil bescheindenlichen varn
###### 1487 | ### Der ist so grimmes mvotes der lat ivch niht genesen ### irn welt mit guoten sinnen bi dem helde wesen ### welt ir daz er ivch fuere so gebet ir im den solt ### her huetet disses landes vn– ist Gelfrate holt
###### 1488 | ### Vn– chomet er niht ecite so ruefet vber fluot ### vn– iehet ir haizet Amelrich des was ein helt gvot ### der durch veintschefte ruomte dize lant ### so chvmet iv der verge swenne im der name wirt erkant
###### 1489 | ### Der ubermvote Hagne den vrovwen do neich ### er en reite niht mere wan daz er stille sweich ### do gie er bi dem wazzer hoher an den sant ### da er anderthalben ein herberge vant
###### 1490 | ### Er begvnde ruofen vaste vber die fluot ### nv hol mich hie verge sprach der degen guot ### so gib ich dir ze miete von golde einen bovc vil rot ### ia ist mir dirre verte werlichen not
###### 1491 | ### Der verge waz so riche daz er niht dienen zam ### da von er lon vil selten von ieman da genam ### ovch waren sine chnehte vil hohe gemvot ### noch stvont allez Hagne hie dishalp der fluot
###### 1492 | ### Do ruoft er mit der kefte daz al der wac erdoz ### von des heldes sterke div was michel vn– groz ### nv hol mich Almerichen ich bin der Eisen man ### der durch starke vintschaft von disem lande entran
###### 1493 | ### Vi hohe an eime swerte ein bovc er im do bot ### lieht vn– schoene was er vol goldes rot ### daz man in vber fuorte in Gelphates lant ### der vbermvote verge nam selbe daz ruoder an die hant
###### 1494 | ### Ovch was der selbe schifman mvolich gesit ### div gir nach grozem guote vil boser ende git ### do wolt er verdienen daz Hagnen golt vil rot ### des leit er von dem degne den swertgrimegen tot
###### 1495 | ### Der verge fuor genote hinvber an den sant ### den er dannen horte do er des niht envant ### do zvrnt er erliche do er Hagnen sach [61a] ### vil harte grimmeclichen er do zuo dem helde sprach
###### 1496 | ### Ir mvget wol sin geheizen bi namen Amerlich ### des ich mich hie verwene den sit ir vngelich ### von vater vnd von mvoter was er der bruoder min ### nv ir mich betrogen habet ir mvoset dishalben sin
###### 1497 | ### Nein durch got den richen sprach do Hagne ### ich bin ein vremder reke vn– sorge vf degene ### nv nemt hin vrivntliche minen solt ### daz ir mich vber fuoret ich bin iv werlichen holt
###### 1498 | ### Do sprach aber der verge desen mach niht gesin ### ez habent viende die lieben herren min ### darum ich niemen vremden fuor in dize lant ### so lieb dir si ze lebene so trit vil balde vz an daz lant
###### 1499 | ### Nvn tuot des niht sprach Hagne trûrich ist min mvot ### nemt von mir ze minnen dize golt vil gvot ### vn– fuerent vns vber tvosent ros vn– also manic man ### do sprach der grimme verge daz wirdet nimmer getan
###### 1500 | ### Er huop ein starkez ruoder michel vn– breit ### er slvoch vf Hagenen des wart er vngemeit ### daz er in dem schife struhte an siniv knie ### so rehte grimmer verge kom zvo dem Troniære nie
###### 1501 | ### Do wolt er baz erzvrnen den vbermvoten gast ### er sluoch im ein schalten daz div gar zerbrast ### Hagnen vber hovbet er was ein starker man ### da von der Eisen verge den grozen schaden gewan
###### 1502 | ### Mit grimmegem mvote greif Hagne zehant ### vil balde ze einer schaide da er ein wafen vant ### er sluoch im ab daz havbet vn– warf ez an den grunt ### div mere wurden schiere den Burgonden kvnt
###### 1503 | ### In den selben stvnden da er den schifman sluoch ### daz schif floz enovwe daz was im leit genvoch ### ê erz gerihte widere mveden er began ### do zoch vil kreftecliche des kvnich Gvnthers man
###### 1504 | ### Mit zvgen harte swinden kerte ez der gast ### vnz im daz starche ruoder an siner hant cebrast ### er wolde zvo den reken vz an einen sant ### da was da heinz mere hei wie schiere erz gebant
###### 1505 | ### mit eime schiltvezzel das was ein borte smal ### gegen eime walde kerte er hin zetal ### do wand er sinen herren an dem stade stan ### do gie im hin enkegene manic wetlicher man
###### 1506 | ### Mit gruoze im wol enphiengen die edelen riter guot ### do sahens in dem schiffe riechen daz bluot ### von einer starken wunden die er den vergen sluoc ### do wart von degnen Hagne gevraget genvoc
###### 1507 | ### Do der kvnich Gvnther daz heize bluot ersach ### sweben in dem schife balde er do sprach ### saget mir her Hagne war ist der verge komen ### iwer starkez ellen wen im den namen hat benomen
###### 1508 | ### Do sprach er lovgenliche da ich daz schif vant [61b] ### bi einer wilden widen da lostez min hant ### ich han deheinen vergen hivte hie gesehen ### ez ist ovch niemen leide von minen schulden geschehen
###### 1509 | ### Do sprach von Burgonden der herre Gernot ### hivte mvoz ich sorgen vf lieber vriunde tot ### sit wir der schiflivte niht bereit han ### wie wir komen vbere des mvoz ich trûrich gestan
###### 1510 | ### Lûte rief do Hagne leget nider vf das gras ### ir knehte daz gereite ich gedenke daz ich was ### der aller beste verge den man bi Rine vant ### ia trovwe ich ivch wol bringen vber in Gelfrates lant
###### 1511 | ### Daz si deste balder komen vber fluot ### div ros si an slvogen der swimmen daz wart guot ### wan der starken vnden deheinz in da benam ### etlichez ovwete als im div muede gezam
###### 1512 | ### Do truogen si ze scife ir golt vnd ovch ir wat ### sit si der verte niht mohten haben rat ### Hagne der was meister des fuorer vf den sant ### vil manigen zieren reken in daz vnkvnde lant
###### 1513 | ### Zem ersten braht er vber tvsent riter her ### darzuo sine reken dannoch was ir mer ### nivn tvsent knehte fuort er an daz lant ### des tages was vnmuozich des kuenen Troniares hant
###### 1514 | ### Do er si wol gesvnde brahte vber vluot ### do gedahte vremder mere der snelle degen guot ### div im ê seiten div wilde merwip ### des hete des kvniges kapelan nach verlorn den lip
###### 1515 | ### Bi dem kapelsovme er den pfaffen vant ### ob dem heilictvme er leinte an siner hant ### des mohte er niht geniezen do in Hagne sach ### der gotes arme priester mvose liden vngemach
###### 1516 | ### Er swanc in vz dem scheffe darzvo wart im gah ### do riefen ir genuoge nv vaha here vah ### Giselher der iunge zvrnen erz began ### ern woltez doch niht lazen eren het im leide getan
###### 1517 | ### Do sprach von Burgvnden der herre Gernot ### waz hilfet ivch nv Hagne des kapelans tot ### tetez ander ieman ez solt iv wesen leit ### vmb welhe schvlde habet ir dem priester widerseit
###### 1518 | ### Der pfaffe swam genote er wolte sein genesen ### ob im ieman hvlfe des mohte do niht wesen ### wan der starke Hagne vil zornich was sin mvot ### er stiez in zvo dem grvnde daz endvhte nieman gvot
###### 1519 | ### Do der arme phaffe der helfe niht ensach ### do kert er wider vbere des leit er vngemach ### swie er niht swimmen kvnde im half div gotes hant ### daz er kom gesvnder hin wider vz an daz lant
###### 1520 | ### Do stuont der arme priester vnde svochte sine wat ### da bi sach wol Hagne daz sin niht wære rat ### daz im fur mere sagten div wilden merwip [62a] ### er dahte dise degene die mvozen verliesen den lip
###### 1521 | ### Do si daz schif entluoden vn– gar getruogen dan ### swaz dar vffe heten der drier kvnige man ### Hagne ez sluoch ze stvken vn– warf ez an die fluot ### des hete michel wunder die reken kuene vn– guot
###### 1522 | ### Zwiv tuot ir dar bruoder so sprach <Dancwart> ### wie svln wir komen vbere so wir die widervart ### riten von den Hvnen ze lande an den Rin ### sit do sagt im Hagne daz des kvnde niht gesin
###### 1523 | ### Do sprach von Troni Hagne ich tvonz vf den wan ### ob wir an diser reise deheinen zagen han ### der vns entrinnen welle durch zegliche not ### der muoz an disem wege liden schemlichen tot
###### 1524 | ### Si fuort mit in einen vz Burgonden lant ### zvo sinen handen einen helt der was Volcher genant ### der reite spiheliche allen sinen mvot ### swaz ie begie Hagne daz duhte den videlere guot
###### 1525 | ### Ir ros bereitet waren ir sovmer wol geladen ### si hete an der verte noch deheinen schaden ### genomen des si mvote wan des chvniges kapelan ### der muose vf sine fuoze hin wider zuo dem Rine gan

<<< Übersicht <<< vorige Seite nächste Seite >>>